<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class Roles extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
        $roles = Role::all();
        return view('admin.roles.index', ['roles' => $roles]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
        return view('admin.roles.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        $validator = Validator::make($request->only('name'), [
            'name' => ['required', 'string', 'max:50', Rule::unique(Role::class)]
        ]);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();

        $role = Role::create([
            'name' => $input['name'],
        ]);

        if(!$role->save()) {
            return redirect()->back()->withInput()->with('error', 'Rolle konnte nicht erstellt werden!');
        }

        return redirect()->route('admin.roles.index')->with('success', 'Rolle wurde erstellt.');
    }

    /**
     * Display the specified resource.
     */
    public function show(Role $role)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Role $role)
    {
        //
        return view('admin.roles.edit', ['role' => $role, 'permissions' => Permission::where('only_user', false)->get()]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Role $role)
    {
        //
        $validator = Validator::make($request->only('name'), [
            'name' => ['required', 'string', 'max:50', Rule::unique(Role::class)->ignore($role->id)]
        ]);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();
        $permissions = $request->input('permissions', []);

        $role->fill($input);
        $role->syncPermissions($permissions);

        if(!$role->save()) {
            return redirect()->back()->withInput()->with('error', 'Rolle konnte nicht gespeichert werden!');
        }

        return redirect()->route('admin.roles.index')->with('success', 'Rolle wurde gespeichert.');
    }

    public function delete(Role $role) {
        return view('admin.roles.delete', ['role' => $role]);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Role $role)
    {
        if(!$role->delete()) {
            return redirect()->route('admin.roles.index')->with('error', 'Rolle konnte nicht gelöscht werden.');
        }

        return redirect()->route('admin.roles.index')->with('success', 'Rolle wurde gelöscht.');
    }
}
