<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Team;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Illuminate\Validation\Rules\Password;
use Spatie\Permission\Models\Role;

class Users extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $users = User::all();

        return view('admin.users.index', ['users' => $users]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
        return view('admin.users.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'name' => ['required', 'string', 'max:255'],
            'email' => [
                'required',
                'string',
                'email',
                'max:255',
                Rule::unique(User::class),
            ],
            'password' => ['required', 'string', Password::min(8), 'confirmed'],
        ]);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();

        $user = User::create([
            'name' => $input['name'],
            'email' => $input['email'],
            'password' => Hash::make($input['password']),
        ]);

        if(!$user->save()) {
            return redirect()->back()->withInput()->with('error', 'User konnte nicht erstellt werden. PennA!');
        }

        return redirect()->route('admin.users.index')->with('success', 'User wurde erstellet.');
    }

    /**
     * Display the specified resource.
     */
    public function show(User $user)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(User $user)
    {
        return view('admin.users.edit', ['user' => $user, 'roles' => Role::all(), 'teams' => Team::all()]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, User $user)
    {
        $rules = [
            'name' => ['required', 'string', 'max:255'],
            'email' => [
                'required',
                'string',
                'email',
                'max:255',
                Rule::unique(User::class)->ignore($user->id),
            ],
        ];

        if($request->input('password')) {
            $rules['password'] = ['required', 'string', Password::min(8), 'confirmed'];
        }

        $validator = Validator::make($request->all(), $rules);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();
        $roles = $request->get('roles', []);
        $teams = $request->get('teams', []);

        $user->fill($input);
        $user->syncRoles($roles);
        $user->syncTeams($teams);

        if($request->input('password')) {
            $user->password = Hash::make($input['password']);
        }

        if(!$user->save()) {
            return redirect()->back()->withInput()->with('error', 'User konnte nicht gespeichert werden. PennA!');
        }

        return redirect()->back()->with('success', 'User wurde gespeichert.');
    }

    public function delete(User $user) {
        return view('admin.users.delete', ['user' => $user]);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(User $user)
    {
        if(!$user->delete()) {
            return redirect()->route('admin.users.index')->with('error', 'User konnte nicht gefickt werden.');
        }

        return redirect()->route('admin.users.index')->with('success', 'User wurde gefickt.');
    }
}
