<?php

namespace App\Http\Controllers\Installer;

use App\Helpers\Installer\EnvironmentManager;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class EnvironmentController extends Controller
{
    protected $manager;

    //
    public function __construct(EnvironmentManager $environmentManager) {
        $this->manager = $environmentManager;
    }

    public function index() {
        $envConfig = $this->manager->getEnvContent();

        return view('_installer.environment', compact('envConfig'));
    }

    public function store(Request $request) {
        $rules = config('installer.environment.form.rules');

        $validator = Validator::make($request->input(), $rules);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        if(!$this->checkDatabaseConnection($request)) {
            return redirect()->back()->withInput()->withErrors([
                'database_connection' => 'Es konnte keine Verbindung zum Datenbank Server hergestellt werden.'
            ]);
        }

        $results = $this->manager->saveFileWizard($request);

        return redirect()->route('installer.database')->with(['results' => $results]);
    }

    private function checkDatabaseConnection(Request $request) {
        $settings = config('database.connections.mysql');

        config([
            'database' => [
                'default' => 'mysql',
                'connections' => [
                    'mysql' => array_merge($settings, [
                        'driver' => 'mysql',
                        'host' => $request->input('database_hostname'),
                        'port' => $request->input('database_port'),
                        'database' => $request->input('database_name'),
                        'username' => $request->input('database_username'),
                        'password' => $request->input('database_password'),
                    ])
                ]
            ]
        ]);

        try {
            DB::connection()->getPdo();

            return true;
        } catch(\Exception $e) {
            return false;
        }
    }
}
