<?php

namespace App\Http\Controllers;

use App\Models\Team;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Spatie\Permission\Models\Role;

class TeamsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
        return view('teams.index', ['teams' => auth()->user()->teams]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     */
    public function show(Team $team)
    {
        //
        return view('teams.show', ['team' => $team]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Team $team)
    {
        //
        return view('teams.manage', ['team' => $team]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Team $team)
    {
        //
        $validator = Validator::make($request->only(['description', 'goals', 'trainings', 'positions']), [
            'description' => ['nullable', 'string'],
            'goals' => ['nullable', 'string'],
            'trainings.*.day' => ['nullable', 'string'],
            'trainings.*.start' => ['nullable', 'string'],
            'trainings.*.end' => ['nullable', 'string'],
            'positions.*.file' => ['nullable', 'image'],
            'positions.*.name' => ['nullable', 'string'],
            'logo' => ['nullable', 'image']
        ]);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();
        $positions = $request->input('positions', []);
        $tpositions = $team->positions;

        if($request->hasFile('logo')) {
            if($team->logo) {
                Storage::delete('teams/'.$team->logo);
            }

            $file = $request->file('logo');
            $file->storeAs('teams/', $file->hashName(), 'public');
            $input['logo'] = $file->hashName();
        }

        $team->fill($input);
        $team->trainings = array_values($request->input('trainings', []));

        usort($team->trainings, function($a, $b) {
            return strcmp($a['day'], $b['day']);
        });

        foreach($positions as $index => $param) {
            if($request->hasFile('positions.'.$index.'.file')) {
                if(isset($tpositions[$index]) && !empty($tpositions[$index]['file'])) {
                    Storage::delete('images/' . $tpositions[$index]['file']);
                }

                $file = $request->file('positions.' . $index . '.file');
                $file->storeAs('images', $file->hashName(), 'public');

                $positions[$index]['file'] = $file->hashName();
            } else {
                $positions[$index]['file'] = $tpositions[$index]['file'];
            }

            $positions[$index]['key'] = Str::lower(Str::slug($positions[$index]['name']));
        }

        $team->positions = array_values($positions);

        if(!$team->save()) {
            return redirect()->back()->withInput()->with('error', 'Team konnte nicht gespeichert werden!');
        }

        return redirect()->route('teams.manage', $team)->with('success', 'Team wurde gespeichert.');
    }

    public function members(Team $team) {
        return view('teams.members', ['team' => $team, 'users' => User::all()]);
    }

    public function updateMembers(Request $request, Team $team) {
        $validator = Validator::make($request->only(['members']), [
            'members' => ['nullable', 'array'],
        ]);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();
        $members = [];

        foreach($input['members'] as $key => $member) {
            $members[$member] = ['position' => $key];
        }

        $team->members()->sync($members);

        if(!$team->save()) {
            return redirect()->back()->withInput()->with('error', 'Mitglieder konnte nicht gespeichert werden!');
        }

        return redirect()->route('teams.show', $team)->with('success', 'Mitglieder wurde gespeichert.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Team $team)
    {
        //
    }
}
