<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Illuminate\Validation\Rules\Password;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     */
    public function show(User $user)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(User $user)
    {
        //
        $user = auth()->user();

        return view('user.edit', ['user' => $user]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, User $user)
    {
        $user = auth()->user();

        $rules = [
            'name' => ['required', 'string', 'max:255'],
            'email' => [
                'required',
                'string',
                'email',
                'max:255',
                Rule::unique(User::class)->ignore($user->id),
            ],
            'avatar' => ['nullable', 'image'],
        ];

        if($request->input('password')) {
            $rules['password'] = ['required', 'string', Password::min(8), 'confirmed'];
        }

        $validator = Validator::make($request->only('email', 'name', 'password', 'avatar'), $rules);

        if($validator->fails()) {
            return redirect()->back()->withInput()->withErrors($validator->errors());
        }

        $input = $validator->validated();

        if($request->hasFile('avatar')) {
            if($user->avatar) {
                Storage::delete('avatars/'.$user->avatar);
            }

            $file = $request->file('avatar');
            $file->storeAs('avatars/', $file->hashName(), 'public');
            $input['avatar'] = $file->hashName();
        }

        $user->fill($input);

        if($request->input('password')) {
            $user->password = Hash::make($input['password']);
        }

        if(!$user->save()) {
            return redirect()->back()->withInput()->with('error', 'Es ist ein Fehler beim Speichern des Profils aufgetreten.');
        }

        return redirect()->back()->with('success', 'Dein Profil wurde gespeichert.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(User $user)
    {
        //
    }
}
