<?php

namespace Database\Seeders;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void
    {
        $this->command->call('migrate:refresh');
        $this->command->warn('Data cleared, starting from blank database.');

        // Seed default permissions
        $permissions = $this->defaultPermissions();

        foreach($permissions as $perm) {
            Permission::firstOrCreate($perm);
        }

        $this->command->info('Default Permissions added!');

        $roles = ['Admin', 'Game Manager', 'User'];

        foreach($roles as $name) {
            $role = Role::firstOrCreate(['name' => trim($name)]);

            $this->command->info($name.' role created');

            if($role->name === 'Admin') {
                // assign all permissions
                $role->syncPermissions(Permission::all());
                $this->command->info('Admin granted all the permissions');
            } elseif($role->name === 'Game Manager') {
                $role->syncPermissions(['teams.management', 'teams.delete', 'teams.edit', 'teams.create']);
                $this->command->info('Game Manager granted the permissions');
            }
        }

        $this->command->info('All done :)');
    }

    private function defaultPermissions() {
        return [
            ['name' => 'admin.open', 'description' => 'Administration öffnen'],
            ['name' => 'permissions.create', 'description' => 'Create permissions'],
            ['name' => 'roles.create', 'description' => 'Create permissions'],
            ['name' => 'roles.edit', 'description' => 'Edit roles'],
            ['name' => 'roles.delete', 'description' => 'Delete roles'],
            ['name' => 'users.create', 'description' => 'Create users'],
            ['name' => 'users.edit', 'description' => 'Edit users'],
            ['name' => 'users.delete', 'description' => 'Delete users'],
            ['name' => 'games.create', 'description' => 'Create games'],
            ['name' => 'games.edit', 'description' => 'Edit games'],
            ['name' => 'games.delete', 'description' => 'Delete games'],
            ['name' => 'games.manage.*', 'description' => 'Manage ALL Games'],
            ['name' => 'teams.create', 'description' => 'Create teams'],
            ['name' => 'teams.edit', 'description' => 'Edit teams'],
            ['name' => 'teams.delete', 'description' => 'Delete teams'],
            ['name' => 'teams.manage.*', 'description' => 'Manage ALL Teams'],
            ['name' => 'teams.management', 'description' => 'Open Team Management'],
        ];
    }
}
