@extends('_installer._layout')

@section('title', 'Environment')

@section('content')
    <div class="text-sm font-medium text-center text-gray-500 border-b border-gray-200 dark:text-gray-400 dark:border-gray-700">
        <ul class="flex flex-wrap -mb-px">
            <li class="me-2">
                <a href="#" onclick="changeTab('environment')" class="inline-block p-4 border-b-2 border-transparent rounded-t-lg hover:border-gray-300 hover:text-gray-300 text-blue-500 border-blue-500" id="tab-environment">
                    <i class="fa fa-cog fa-fw" aria-hidden="true"></i>
                    Environment
                </a>
            </li>
            <li class="me-2">
                <a href="#" onclick="changeTab('database')" class="inline-block p-4 border-b-2 border-transparent rounded-t-lg hover:border-gray-300 hover:text-gray-300" id="tab-database">
                    <i class="fa fa-database fa-fw" aria-hidden="true"></i>
                    Database
                </a>
            </li>
            <li class="me-2">
                <a href="#" onclick="changeTab('application')" class="inline-block p-4 border-b-2 border-transparent rounded-t-lg hover:border-gray-300 hover:text-gray-300" id="tab-application">
                    <i class="fa fa-cogs fa-fw" aria-hidden="true"></i>
                    Application
                </a>
            </li>
        </ul>
    </div>


    <div class="px-2 py-3">
        <form method="post" action="{{ route('installer.environment') }}" class="tabs-wrap">
            @csrf

            <div class="" id="content-environment">
                <div class="mb-3 {{ $errors->has('app_name') ? ' has-error ' : '' }}">
                    <label for="app_name">
                        Sitetitle
                    </label>
                    <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="app_name" id="app_name" value="{{ old('app_name') }}" placeholder="Sitetitle" />
                    @if ($errors->has('app_name'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('app_name') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('environment') ? ' has-error ' : '' }}">
                    <label for="environment">
                        Environment
                    </label>
                    <select class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="environment" id="environment">
                        <option value="local" selected>Local</option>
                        <option value="development">Development</option>
                        <option value="production">Production</option>
                    </select>
                    @if ($errors->has('environment'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('environment') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('app_debug') ? ' has-error ' : '' }}">
                    <label for="app_debug">
                        Debug
                    </label>

                    <div class="flex">
                        <div class="flex items-center me-4">
                            <input type="radio" name="app_debug" id="app_debug_true" value="true" class="w-4 h-4 text-blue-600 bg-gray-100 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" checked>
                            <label for="app_debug_true" class="ms-2 text-sm font-medium text-gray-900 dark:text-gray-300">Ja</label>
                        </div>
                        <div class="flex items-center">
                            <input type="radio" name="app_debug" id="app_debug_false" value="false" class="w-4 h-4 text-blue-600 bg-gray-100 border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600">
                            <label for="app_debug_false" class="ms-2 text-sm font-medium text-gray-900 dark:text-gray-300">Nein</label>
                        </div>
                    </div>

                    @if ($errors->has('app_debug'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('app_debug') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('app_log_level') ? ' has-error ' : '' }}">
                    <label for="app_log_level">
                        Log Level
                    </label>
                    <select class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="app_log_level" id="app_log_level">
                        <option value="debug">Debug</option>
                        <option value="info">Info</option>
                        <option value="notice">Notice</option>
                        <option value="warning" selected>Warning</option>
                        <option value="error">Error</option>
                        <option value="critical">Critical</option>
                        <option value="alert">Alert</option>
                        <option value="emergency">Emergency</option>
                    </select>
                    @if ($errors->has('app_log_level'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('app_log_level') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('app_url') ? ' has-error ' : '' }}">
                    <label for="app_url">
                        Siteurl
                    </label>
                    <input type="url" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="app_url" id="app_url" value="{{ old('app_url', 'http://localhost') }}" placeholder="http://monster010.de" />
                    @if ($errors->has('app_url'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('app_url') }}
                        </span>
                    @endif
                </div>

                <div class="flex justify-end mt-4">
                    <button type="button" onclick="changeTab('database')" class="px-3 py-1 bg-green-500 rounded border border-green-600 hover:bg-green-600">
                        Datenbank Einstellungen
                        <i class="fa fa-angle-right fa-fw" aria-hidden="true"></i>
                    </button>
                </div>
            </div>

            <div class="hidden" id="content-database">
                <div class="mb-3 {{ $errors->has('database_connection') ? ' has-error ' : '' }}">
                    <label for="database_connection">
                        Datenbank Typ
                    </label>
                    <select class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="database_connection" id="database_connection">
                        <option value="mysql" selected>MySQL / MariaDB</option>
                    </select>
                    @if ($errors->has('database_connection'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('database_connection') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('database_hostname') ? ' has-error ' : '' }}">
                    <label for="database_hostname">
                        Hostname
                    </label>
                    <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="database_hostname" id="database_hostname" value="{{ old('database_hostname', '127.0.0.1') }}" placeholder="Hostname" />
                    @if ($errors->has('database_hostname'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('database_hostname') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('database_port') ? ' has-error ' : '' }}">
                    <label for="database_port">
                        Port
                    </label>
                    <input type="number" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="database_port" id="database_port" value="{{ old('database_port', '3306') }}" placeholder="Port" />
                    @if ($errors->has('database_port'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('database_port') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('database_name') ? ' has-error ' : '' }}">
                    <label for="database_name">
                        Datenbank Name
                    </label>
                    <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="database_name" id="database_name" value="{{ old('database_name', 'ifc_manage') }}" placeholder="Datenbank Name" />
                    @if ($errors->has('database_name'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('database_name') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('database_username') ? ' has-error ' : '' }}">
                    <label for="database_username">
                        Username
                    </label>
                    <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="database_username" id="database_username" value="{{ old('database_username', 'root') }}" placeholder="Username" />
                    @if ($errors->has('database_username'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('database_username') }}
                        </span>
                    @endif
                </div>

                <div class="mb-3 {{ $errors->has('database_password') ? ' has-error ' : '' }}">
                    <label for="database_password">
                        Password
                    </label>
                    <input type="password" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="database_password" id="database_password" value="" placeholder="Passwort" />
                    @if ($errors->has('database_password'))
                        <span class="error-block">
                            <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                            {{ $errors->first('database_password') }}
                        </span>
                    @endif
                </div>


                <div class="flex justify-end mt-4">
                    <button type="button" onclick="changeTab('application')" class="px-3 py-1 bg-green-500 rounded border border-green-600 hover:bg-green-600">
                        App Einstellungen
                        <i class="fa fa-angle-right fa-fw" aria-hidden="true"></i>
                    </button>
                </div>
            </div>

            <div class="hidden" id="content-application">
                <div class="block">
                    <div class="info">
                        <div class="mb-3 {{ $errors->has('mail_driver') ? ' has-error ' : '' }}">
                            <label for="mail_driver">
                                Mail Driver
                            </label>
                            <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="mail_driver" id="mail_driver" value="smtp" placeholder="Mail Driver" readonly />
                            @if ($errors->has('mail_driver'))
                                <span class="error-block">
                                    <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                                    {{ $errors->first('mail_driver') }}
                                </span>
                            @endif
                        </div>

                        <div class="mb-3 {{ $errors->has('mail_host') ? ' has-error ' : '' }}">
                            <label for="mail_host">Mail Host</label>
                            <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="mail_host" id="mail_host" value="{{ old('mail_host') }}" placeholder="Mail Host" />
                            @if ($errors->has('mail_host'))
                                <span class="error-block">
                                    <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                                    {{ $errors->first('mail_host') }}
                                </span>
                            @endif
                        </div>

                        <div class="mb-3 {{ $errors->has('mail_port') ? ' has-error ' : '' }}">
                            <label for="mail_port">Mail Port</label>
                            <input type="number" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="mail_port" id="mail_port" value="{{ old('mail_port', 25) }}" placeholder="Mail Port" />
                            @if ($errors->has('mail_port'))
                                <span class="error-block">
                                    <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                                    {{ $errors->first('mail_port') }}
                                </span>
                            @endif
                        </div>

                        <div class="mb-3 {{ $errors->has('mail_username') ? ' has-error ' : '' }}">
                            <label for="mail_username">Mail Username</label>
                            <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="mail_username" id="mail_username" value="{{ old('mail_username') }}" placeholder="Mail Username" />
                            @if ($errors->has('mail_username'))
                                <span class="error-block">
                                    <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                                    {{ $errors->first('mail_username') }}
                                </span>
                            @endif
                        </div>

                        <div class="mb-3 {{ $errors->has('mail_password') ? ' has-error ' : '' }}">
                            <label for="mail_password">Mail Passwort</label>
                            <input type="password" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="mail_password" id="mail_password" placeholder="Passwort" />
                            @if ($errors->has('mail_password'))
                                <span class="error-block">
                                    <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                                    {{ $errors->first('mail_password') }}
                                </span>
                            @endif
                        </div>

                        <div class="mb-3 {{ $errors->has('mail_encryption') ? ' has-error ' : '' }}">
                            <label for="mail_encryption">Encryption</label>
                            <input type="text" class="bg-neutral-700 border border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" name="mail_encryption" id="mail_encryption" value="{{ old('mail_encryption') }}" placeholder="Encryption" />
                            @if ($errors->has('mail_encryption'))
                                <span class="error-block">
                                    <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
                                    {{ $errors->first('mail_encryption') }}
                                </span>
                            @endif
                        </div>
                    </div>
                </div>

                <div class="flex justify-end mt-4">
                    <button type="submit" class="px-3 py-1 bg-green-500 rounded border border-green-600 hover:bg-green-600">
                        Install
                        <i class="fa fa-angle-right fa-fw" aria-hidden="true"></i>
                    </button>
                </div>
            </div>
        </form>

    </div>
@endsection

@section('scripts')
    <script type="text/javascript">
        function changeTab(tab) {
            if(tab === 'environment') {
                document.getElementById('content-environment').classList.remove('hidden')
                document.getElementById('tab-environment').classList.add('text-blue-500', 'border-blue-500')

                document.getElementById('content-database').classList.add('hidden')
                document.getElementById('tab-database').classList.remove('text-blue-500', 'border-blue-500')

                document.getElementById('content-application').classList.add('hidden')
                document.getElementById('tab-application').classList.remove('text-blue-500', 'border-blue-500')
            } else if(tab === 'database') {
                document.getElementById('content-environment').classList.add('hidden')
                document.getElementById('tab-environment').classList.remove('text-blue-500', 'border-blue-500')

                document.getElementById('content-database').classList.remove('hidden')
                document.getElementById('tab-database').classList.add('text-blue-500', 'border-blue-500')

                document.getElementById('content-application').classList.add('hidden')
                document.getElementById('tab-application').classList.remove('text-blue-500', 'border-blue-500')
            } else if(tab === 'application') {
                document.getElementById('content-environment').classList.add('hidden')
                document.getElementById('tab-environment').classList.remove('text-blue-500', 'border-blue-500')

                document.getElementById('content-database').classList.add('hidden')
                document.getElementById('tab-database').classList.remove('text-blue-500', 'border-blue-500')

                document.getElementById('content-application').classList.remove('hidden')
                document.getElementById('tab-application').classList.add('text-blue-500', 'border-blue-500')
            }
        }
    </script>
@endsection
