@extends('_layouts.backend')

@section('title', 'Games')

@section('content')
    <div class="flex justify-between mb-6">
        <h3 class="font-bold text-2xl">Games</h3>

        <div class="space-x-2">
            @can('games.create')
                <a href="{{ route('admin.games.create') }}"
                   class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                    Create
                </a>
            @endcan
        </div>
    </div>

    @if($errors->any())
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            <ul>
                @foreach($errors->all() as $error)
                    <li>
                        {{$error}}
                    </li>
                @endforeach
            </ul>
        </div>
    @endif

    @if(session('error'))
        <x-alert type="error" :message="session('error')"></x-alert>
    @endif

    @if(session('success'))
        <x-alert type="success" :message="session('success')"></x-alert>
    @endif

    <div class="relative overflow-x-auto shadow-md sm:rounded-lg">
        <table class="w-full text-sm text-left rtl:text-right text-gray-500 dark:text-gray-400">
            <thead class="text-xs text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
            <tr>
                <th class="px-6 py-3">ID</th>
                <th class="px-6 py-3">Name</th>
                <th class="px-6 py-3">Manager</th>
                <th class="px-6 py-3"></th>
            </tr>
            </thead>
            <tbody>
            @foreach($games as $game)
                <tr class="odd:bg-neutral-900 even:bg-neutral-800 border-b border-gray-700">
                    <td class="px-6 py-4">{{ $game->id }}</td>
                    <td class="px-6 py-4">{{ $game->name }} ({{ $game->short }})</td>
                    <td class="px-6 py-4">{{ $game->manager->name }}</td>
                    <td class="space-x-2.5">
                        @can('games.edit')
                            <a href="{{ route('admin.games.edit', $game) }}"
                               class="bg-amber-700 rounded-full py-1.5 px-3 text-white hover:bg-amber-900 drop-shadow">
                                Edit</a>
                        @endcan
                        @can('games.delete')
                            <a href="{{ route('admin.games.delete', $game) }}"
                               class="bg-red-700 rounded-full py-1.5 px-3 text-white hover:bg-red-900 drop-shadow">
                                Delete</a>
                        @endcan
                    </td>
                </tr>
            @endforeach
            </tbody>
        </table>
    </div>
@endsection
