@extends('_layouts.backend')

@section('title', 'Rolle '.$role->name.' bearbeiten')

@section('content')
    <div class="flex justify-between mb-6">
        <h3 class="font-bold text-2xl">Edit role {{ $role->name }}</h3>
    </div>

    @if($errors->any())
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            <ul>
                @foreach($errors->all() as $error)
                    <li>
                        {{$error}}
                    </li>
                @endforeach
            </ul>
        </div>
    @endif

    @if(session('error'))
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            {{session('error')}}
        </div>
    @endif

    @if(session('success'))
        <div class="bg-green-500 text-green-950 p-3 rounded my-3">
            {{session('success')}}
        </div>
    @endif

    <form action="{{ route('admin.roles.edit', $role->id) }}" method="Post">
        @csrf
        <!-- username -->
        <div class="mb-6">
            <label for="name" class="block mb-2 text-sm font-medium">
                Name
            </label>
            <input type="text" id="name" name="name" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="role name" required value="{{old('name', $role->name)}}">
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>

        <hr class="my-6">

        <div class="flex justify-between my-6">
            <h4 class="font-bold text-xl">Permissions</h4>
        </div>

        <div class="grid grid-cols-2 md:grid-cols-3 gap-4">
            @foreach($permissions as $permission)
                <div class="flex items-center ps-4 border rounded border-gray-700">
                    <input id="permission-{{ $permission->id }}"
                           {{ $role->hasPermissionTo($permission->name) ? 'checked' : '' }} type="checkbox"
                           value="{{ $permission->name }}" name="permissions[]"
                           class="w-4 h-4 text-blue-600 rounded focus:ring-blue-600 ring-offset-gray-800 ring-2 bg-gray-700 border-gray-600">
                    <label for="permission-{{ $permission->id }}"
                           class="w-full py-4 ms-2 text-sm font-medium text-gray-300">{{ $permission->description }}</label>
                </div>
            @endforeach
        </div>

        <!-- placeholder -->
        <div class="my-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>
    </form>
@endsection
