@extends('_layouts.backend')

@section('title', 'User '.$user->name.' bearbeiten')

@section('content')
    <div class="flex justify-between mb-6">
        <h3 class="font-bold text-2xl">Edit user {{ $user->name }}</h3>
    </div>

    @if($errors->any())
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            <ul>
                @foreach($errors->all() as $error)
                    <li>
                        {{$error}}
                    </li>
                @endforeach
            </ul>
        </div>
    @endif

    @if(session('error'))
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            {{session('error')}}
        </div>
    @endif

    @if(session('success'))
        <div class="bg-green-500 text-green-950 p-3 rounded my-3">
            {{session('success')}}
        </div>
    @endif

    <form action="{{ route('admin.users.edit', $user->id) }}" method="Post">
        @csrf
        <!-- email -->
        <div class="mb-6">
            <label for="email" class="block mb-2 text-sm font-medium">
                Email
            </label>
            <input type="email" id="email" name="email" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="email" required autocomplete="email"
                   value="{{old('email', $user->email)}}">
        </div>
        <!-- username -->
        <div class="mb-6">
            <label for="name" class="block mb-2 text-sm font-medium">
                Username
            </label>
            <input type="text" id="name" name="name" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="username" required autocomplete="username"
                   value="{{old('name', $user->name)}}">
        </div>
        <!-- password -->
        <div class="mb-6">
            <label for="password" class="block mb-2 text-sm font-medium">
                Password
            </label>
            <input type="password" id="password" name="password" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="password" autocomplete="new-password">
        </div>
        <!-- password confirm-->
        <div class="mb-6">
            <label for="password_confirmation" class="block mb-2 text-sm font-medium">
                Confirm Password
            </label>
            <input type="password" id="password_confirmation" name="password_confirmation" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="confirm password" autocomplete="new-password">
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>

        <hr class="my-6">

        <div class="flex justify-between my-6">
            <h4 class="font-bold text-xl">Roles</h4>
        </div>

        <div class="grid grid-cols-2 md:grid-cols-3 gap-4">
            @foreach($roles as $role)
                <div class="flex items-center ps-4 border rounded border-gray-700">
                    <input id="role-{{ $role->id }}" {{ $user->hasRole($role->name) ? 'checked' : '' }} type="checkbox"
                           value="{{ $role->name }}" name="roles[]"
                           class="w-4 h-4 text-blue-600 rounded focus:ring-blue-600 ring-offset-gray-800 ring-2 bg-gray-700 border-gray-600">
                    <label for="role-{{ $role->id }}"
                           class="w-full py-4 ms-2 text-sm font-medium text-gray-300">{{ $role->name }}</label>
                </div>
            @endforeach
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>

        <hr class="my-6">

        <div class="flex justify-between my-6">
            <h4 class="font-bold text-xl">Teams</h4>
        </div>

        <div class="grid grid-cols-2 md:grid-cols-3 gap-4">
            @foreach($teams as $team)
                <div class="flex items-center ps-4 border rounded border-gray-700">
                    <input id="team-{{ $team->id }}" type="checkbox"
                           value="{{ $team->id }}" name="teams[]" {{ in_array($team->id, $user->teams()->pluck('id')->toArray()) ? 'checked' : '' }}
                           class="w-4 h-4 text-blue-600 rounded focus:ring-blue-600 ring-offset-gray-800 ring-2 bg-gray-700 border-gray-600">
                    <label for="team-{{ $team->id }}"
                           class="w-full py-4 ms-2 text-sm font-medium text-gray-300">{{ $team->name }}</label>
                </div>
            @endforeach
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>
    </form>
@endsection
