@extends('_layouts.backend')

@section('title', 'Benutzer')

@section('content')
    <div class="flex justify-between mb-6">
        <h3 class="font-bold text-2xl">Users</h3>

        @can('users.create')
            <a href="{{ route('admin.users.create') }}"
               class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                Create
            </a>
        @endcan
    </div>

    @if($errors->any())
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            <ul>
                @foreach($errors->all() as $error)
                    <li>
                        {{$error}}
                    </li>
                @endforeach
            </ul>
        </div>
    @endif

    @if(session('error'))
        <div class="bg-red-500 text-red-950 p-3 rounded my-3">
            {{session('error')}}
        </div>
    @endif

    @if(session('success'))
        <div class="bg-green-500 text-green-950 p-3 rounded my-3">
            {{session('success')}}
        </div>
    @endif

    <div class="relative overflow-x-auto shadow-md sm:rounded-lg">
        <table class="w-full text-sm text-left rtl:text-right text-gray-500 dark:text-gray-400">
            <thead class="text-xs text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
            <tr>
                <th class="px-6 py-3">ID</th>
                <th class="px-6 py-3">Username</th>
                <th class="px-6 py-3">E-Mail</th>
                <th class="px-6 py-3">Rollen</th>
                <th class="px-6 py-3">Created</th>
                <th class="px-6 py-3"></th>
            </tr>
            </thead>
            <tbody>
            @foreach($users as $user)
                <tr class="odd:bg-neutral-900 even:bg-neutral-800 border-b border-gray-700">
                    <td class="px-6 py-4">{{ $user->id }}</td>
                    <td class="px-6 py-4">{{ $user->name }}</td>
                    <td class="px-6 py-4">{{ $user->email }}</td>
                    <td class="px-6 py-4">{{ $user->roles->pluck('name')->implode(', ') }}</td>
                    <td class="px-6 py-4">{{ $user->created_at }}</td>
                    <td class="space-x-2.5">
                        @can('users.edit')
                            <a href="{{ route('admin.users.edit', $user) }}"
                               class="bg-amber-700 rounded-full py-1.5 px-3 text-white hover:bg-amber-900 drop-shadow">
                                Edit</a>
                        @endcan
                        @can('users.delete')
                            <a href="{{ route('admin.users.delete', $user) }}"
                               class="bg-red-700 rounded-full py-1.5 px-3 text-white hover:bg-red-900 drop-shadow">
                                Delete</a>
                        @endcan
                    </td>
                </tr>
            @endforeach
            </tbody>
        </table>
    </div>
@endsection
