@extends('_layouts.app')

@section('title', 'Manage Team '.$team->name)

@section('content')
    <div class="flex justify-between mb-6">
        <h3 class="font-bold text-2xl">Manage Team :: {{ $team->name }}</h3>

        <div class="space-x-2">
            <a href="{{ route('teams.show', $team) }}"
               class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                Zurück
            </a>
        </div>
    </div>

    @include('common.notifications')

    <form action="{{ route('teams.manage', $team) }}" method="POST" enctype="multipart/form-data">
        @csrf
        <!-- username -->
        <div class="mb-6">
            <label for="description" class="block mb-2 text-sm font-medium">
                Beschreibung
            </label>
            <textarea id="description" name="description" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="description" rows="10"
            >{{ old('description', $team->description) }}</textarea>
        </div>
        <!-- username -->
        <div class="mb-6">
            <label for="goals" class="block mb-2 text-sm font-medium">
                Ziele
            </label>
            <textarea id="goals" name="goals" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400" placeholder="goals" rows="10"
            >{{ old('goals', $team->goals) }}</textarea>
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>

        <hr class="my-6">

        <div class="flex justify-between my-6">
            <h4 class="font-bold text-xl">Logo</h4>
        </div>

        @if($team->logo)
            <div class="flex justify-center">
                <div class="border border-gray-700 rounded-lg p-1">
                    <img src="{{ \Illuminate\Support\Facades\Storage::url('teams/'.$team->logo) }}" class="w-16 h-16">
                </div>
            </div>
        @endif

        <!-- username -->
        <div class="mb-6">
            <label for="logo" class="block mb-2 text-sm font-medium">
                Logo
            </label>
            <input type="file" id="logo" name="logo" class="bg-neutral-700 border
            border-gray-600 rounded text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500
            placeholder-gray-400">
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>

        <hr class="my-6">

        <div class="flex justify-between my-6">
            <h4 class="font-bold text-xl">Trainingszeiten</h4>

            <div class="space-x-2">
                <button id="addTraining" type="button"
                   class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                    Zeit hinzufügen
                </button>
            </div>
        </div>

        <div class="mb-6" id="trainings_times">
            @foreach($team->trainings as $index => $training)
                <div class="mb-6 trainings_row">
                    <label for="trainings[{{$index}}][day]" class="block mb-2 text-sm font-medium">
                        Trainingzeit
                    </label>
                    <div class="sm:flex shadow-sm relative">
                        <input type="text" value="{{old("training[$index][day]", $training['day'])}}" id="trainings[{{$index}}][day]" name="trainings[{{$index}}][day]" class="bg-neutral-700 border border-gray-600 rounded-s text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Tag">
                        <input type="text" data-default-date="{{old("training[$index][start]", $training['start'])}}" value="{{old("training[$index][start]", $training['start'])}}" id="trainings[{{$index}}][start]" name="trainings[{{$index}}][start]" class="timepicker bg-neutral-700 border-y border-x-0 border-gray-600 text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Zeit">
                        <input type="text" data-default-date="{{old("training[$index][end]", $training['end'])}}" value="{{old("training[$index][end]", $training['end'])}}" id="trainings[{{$index}}][end]" name="trainings[{{$index}}][end]" class="timepicker bg-neutral-700 border-y border-x-0 border-gray-600 text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Zeit">
                        <button type="button" class="remove_time p-2.5 h-full text-sm font-medium text-white bg-red-700 rounded-e-lg border border-red-700 hover:bg-red-800 focus:ring-4 focus:outline-none focus:ring-red-300">Remove</button>
                    </div>
                </div>
            @endforeach
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>

        <hr class="my-6">

        <div class="flex justify-between my-6">
            <h4 class="font-bold text-xl">Positionen</h4>

            <div class="space-x-2">
                <button id="addPosition" type="button"
                   class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                    Position hinzufügen
                </button>
            </div>
        </div>

        <div class="mb-6" id="positions_rows">
            @foreach($team->positions as $index => $position)
                <div class="mb-6 position_row">
                    <label for="positions[{{$index}}][name]" class="block mb-2 text-sm font-medium">
                        Position
                    </label>
                    <div class="sm:flex shadow-sm relative">
                        <img src="{{ isset($position['file']) ? Storage::url("images/".$position['file']) : ''}}" alt="{{ $position['name'] }} Image" class="mr-3">
                        <div class="w-full flex items-center">
                            <input type="text" id="positions[{{$index}}][name]" name="positions[{{$index}}][name]" value="{{ old("positions[$index][name]", $position['name']) }}" class="bg-neutral-700 border-y border-x-0 border-gray-600 rounded-s text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Position">
                            <button type="button" class="remove_position p-2.5 text-sm font-medium text-white bg-red-700 rounded-e-lg border border-red-700 hover:bg-red-800 focus:ring-4 focus:outline-none focus:ring-red-300">Remove</button>
                        </div>
                    </div>
                </div>
            @endforeach
        </div>

        <!-- placeholder -->
        <div class="mb-3 flex justify-center">
            <button type="submit" class="rounded-full px-6 py-2 bg-violet-700 border border-violet-600 p-1.5">
                submit
            </button>
        </div>
    </form>
@endsection

@section('scripts')
    <script type="module">
        $(document).ready(function() {
            function reloadPicker() {
                flatpickr(".timepicker", {
                    enableTime: true,
                    noCalendar: true,
                    dateFormat: 'H:i',
                    time_24hr: true,
                })
            }

            reloadPicker()

            var trainingsCount = {{ count($team->trainings) }};
            var positionsCount = {{ count($team->positions) }};

            $('#addTraining').click(function() {
                let templateHtml = `<div class="mb-6 trainings_row">
                <label for="trainings[${trainingsCount}][day]" class="block mb-2 text-sm font-medium">
                    Trainingzeit
                </label>
                <div class="sm:flex shadow-sm relative">
                    <input type="text" id="trainings[${trainingsCount}][day]" name="trainings[${trainingsCount}][day]" class="bg-neutral-700 border border-gray-600 rounded-s text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Tag">
                    <input type="text" id="trainings[${trainingsCount}][start]" name="trainings[${trainingsCount}][start]" class="timepicker bg-neutral-700 border-y border-x-0 border-gray-600 text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Zeit">
                    <input type="text" id="trainings[${trainingsCount}][end]" name="trainings[${trainingsCount}][end]" class="timepicker bg-neutral-700 border-y border-x-0 border-gray-600 text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Zeit">
                    <button type="button" class="remove_time p-2.5 h-full text-sm font-medium text-white bg-red-700 rounded-e-lg border border-red-700 hover:bg-red-800 focus:ring-4 focus:outline-none focus:ring-red-300">Remove</button>
                </div>
            </div>`

                $('#trainings_times').append(templateHtml)

                trainingsCount++;

                reloadPicker()
            })

            $(document).on('click', '.remove_time', function() {
                $(this).parents('.trainings_row').remove();
            })

            $('#addPosition').click(function() {
                let templateHtml = `<div class="mb-6 position_row">
                <label for="positions[${positionsCount}][name]" class="block mb-2 text-sm font-medium">
                    Position
                </label>
                <div class="sm:flex shadow-sm relative">
                    <input type="file" accept="image/*" id="positions[${positionsCount}][file]" name="positions[${positionsCount}][file]" class="bg-neutral-700 border border-gray-600 rounded-s text-sm w-full p-2 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="File">
                    <input type="text" id="positions[${positionsCount}][name]" name="positions[${positionsCount}][name]" class="bg-neutral-700 border-y border-x-0 border-gray-600 text-sm w-full p-2.5 focus:ring-violet-500 focus:border-violet-500 placeholder-gray-400" placeholder="Position">
                    <button type="button" class="remove_position p-2.5 h-full text-sm font-medium text-white bg-red-700 rounded-e-lg border border-red-700 hover:bg-red-800 focus:ring-4 focus:outline-none focus:ring-red-300">Remove</button>
                </div>
            </div>`

                $('#positions_rows').append(templateHtml)

                positionsCount++;
            })

            $(document).on('click', '.remove_position', function() {
                $(this).parents('.position_row').remove();
            })
        });
    </script>
@endsection
