@extends('_layouts.app')

@section('title', 'Team '.$team->name)

@section('content')
    <div class="flex justify-between items-center mb-6">
        <div class="flex">
            @if($team->logo)
                <div class="border border-gray-700 rounded-lg p-1 mr-4">
                    <img src="{{ \Illuminate\Support\Facades\Storage::url('teams/'.$team->logo) }}" class="w-16 h-16">
                </div>
            @endif
            <div>
                <h3 class="font-bold text-2xl">Team :: {{ $team->name }}</h3>
                <p>Team erstellt: {{ $team->created_at->format('H:i:s d.m.Y') }}</p>
            </div>
        </div>

        <div class="space-x-2">
            @canany(['teams.manage.'.$team->id, 'games.manage.'.$team->game->id])
                <a href="{{ route('teams.members', $team) }}"
                   class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                    Members
                </a>

                <a href="{{ route('teams.manage', $team) }}"
                   class="bg-green-700 rounded-full py-3 px-6 text-white hover:bg-green-900 drop-shadow">
                    Manage
                </a>
            @endcan
        </div>
    </div>

    @include('common.notifications')

    <div class="relative overflow-x-auto">
        <div class="flex justify-between space-x-2">
            <div class="w-1/2 space-y-2">
                <div class="flex w-full flex-col px-6 py-4 border rounded border-gray-700">
                    <p class="w-full font-semibold text-gray-300">Team Leader</p>
                    <p class="text-sm">{{ $team->leader->name }}</p>
                </div>
                <div class="flex w-full flex-col px-6 py-4 border rounded border-gray-700">
                    <p class="w-full font-semibold text-gray-300">Trainingszeiten</p>

                    <table>
                        @foreach($team->trainings as $index => $training)
                        <tr>
                            <th>{{ $training['day'] }}</th>
                            <td>{{ $training['start'] }}</td>
                            <td>{{ $training['end'] }}</td>
                        </tr>
                        @endforeach
                    </table>
                </div>

                <div class="flex w-full flex-col px-6 py-4 border rounded border-gray-700">
                    <p class="w-full font-semibold text-gray-300">Positionen</p>
                    <div class="grid grid-cols-2 md:grid-cols-3 gap-4">
                        @foreach($team->positions as $index => $position)
                            <div class="sm:flex shadow-sm relative">
                                <img src="{{ isset($position['file']) ? Storage::url("images/".$position['file']) : ''}}" alt="{{ $position['name'] }} Image" class="mr-3">
                                <div class="w-full flex flex-col">
                                    <p class="font-semibold">{{ null !== $team->members()->where('position', $position['key'])->first() ? $team->members()->where('position', $position['key'])->first()->name : 'Nicht besetzt' }}</p>
                                    <p class="text-sm">{{$position['name']}}</p>
                                </div>
                            </div>
                        @endforeach
                    </div>
                </div>
            </div>
            <div class="space-y-2 w-1/2">
                <div class="flex w-full flex-col px-6 py-4 border rounded border-gray-700">
                    <p class="w-full font-semibold text-gray-300">Game</p>
                    <p class="text-sm">{{ $team->game->name }}</p>
                </div>
                <div class="flex w-full flex-col px-6 py-4 border rounded border-gray-700">
                    <p class="w-full font-semibold text-gray-300">Beschreibung</p>
                    <p class="text-sm">{!! nl2br(e($team->description)) !!}</p>
                </div>
                <div class="flex w-full flex-col px-6 py-4 border rounded border-gray-700">
                    <p class="w-full font-semibold text-gray-300">Ziele</p>
                    <p class="text-sm">{!! nl2br(e($team->goals)) !!}</p>
                </div>
            </div>
        </div>
    </div>
@endsection
