<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::prefix('install')->middleware(['canInstall'])->name('installer.')->namespace('App\Http\Controllers\Installer')->group(function() {
    Route::get('/', \App\Http\Controllers\Installer\WelcomeController::class)->name('welcome');
    Route::get('requirements', \App\Http\Controllers\Installer\RequirementsController::class)->name('requirements');
    Route::get('permissions', \App\Http\Controllers\Installer\PermissionsController::class)->name('permissions');
    Route::get('finish', \App\Http\Controllers\Installer\FinishController::class)->name('finish');

    Route::get('database', 'DatabaseController@index')->name('database');
    Route::post('database', 'DatabaseController@run');

    Route::get('environment', 'EnvironmentController@index')->name('environment');
    Route::post('environment', 'EnvironmentController@store');

    Route::get('admin', 'AdminController@index')->name('create_user');
    Route::post('admin', 'AdminController@store');
});

Route::middleware(['auth', 'verified', 'can:admin.open'])->prefix('admin')->name('admin.')->group(function () {
    Route::get('/', 'App\Http\Controllers\Admin\Users@index')->name('dashboard');

    Route::prefix('users')->name('users.')->controller('App\Http\Controllers\Admin\Users')->group(function() {
        Route::get('index', 'index')->name('index');

        Route::get('create', 'create')->name('create')->middleware('can:users.create');
        Route::post('create', 'store')->middleware('can:users.create');

        Route::get('edit/{user}', 'edit')->name('edit')->middleware('can:users.edit');
        Route::post('edit/{user}', 'update')->middleware('can:users.edit');

        Route::get('delete/{user}', 'delete')->name('delete')->middleware('can:users.delete');
        Route::post('delete/{user}', 'destroy')->middleware('can:users.delete');
    });

    Route::prefix('roles')->name('roles.')->controller('App\Http\Controllers\Admin\Roles')->group(function() {
        Route::get('index', 'index')->name('index');

        Route::get('create', 'create')->name('create')->middleware('can:roles.create');
        Route::post('create', 'store')->middleware('can:roles.create');

        Route::get('edit/{role}', 'edit')->name('edit')->middleware('can:roles.edit');
        Route::post('edit/{role}', 'update')->middleware('can:roles.edit');

        Route::get('delete/{role}', 'delete')->name('delete')->middleware('can:roles.delete');
        Route::post('delete/{role}', 'destroy')->middleware('can:roles.delete');
    });

    Route::prefix('games')->name('games.')->controller('App\Http\Controllers\Admin\Games')->group(function() {
        Route::get('index', 'index')->name('index');

        Route::get('create', 'create')->name('create')->middleware('can:games.create');
        Route::post('create', 'store')->middleware('can:games.create');

        Route::get('edit/{game}', 'edit')->name('edit')->middleware('can:games.edit');
        Route::post('edit/{game}', 'update')->middleware('can:games.edit');

        Route::get('delete/{game}', 'delete')->name('delete')->middleware('can:games.delete');
        Route::post('delete/{game}', 'destroy')->middleware('can:games.delete');
    });

    Route::prefix('teams')->name('teams.')->controller('App\Http\Controllers\Admin\Teams')->group(function() {
        Route::get('index', 'index')->name('index');

        Route::get('create', 'create')->name('create')->middleware('can:teams.create');
        Route::post('create', 'store')->middleware('can:teams.create');

        Route::get('edit/{team}', 'edit')->name('edit')->middleware('can:teams.edit');
        Route::post('edit/{team}', 'update')->middleware('can:teams.edit');

        Route::get('delete/{team}', 'delete')->name('delete')->middleware('can:teams.delete');
        Route::post('delete/{team}', 'destroy')->middleware('can:teams.delete');
    });

    Route::prefix('permissions')->name('permissions.')->controller('App\Http\Controllers\Admin\Permissions')->group(function() {
        Route::get('create', 'create')->name('create')->middleware('can:permissions.create');
        Route::post('create', 'store')->middleware('can:permissions.create');
    });
});

Route::middleware(['auth', 'verified'])->group(function() {
    Route::prefix('teams')->name('teams.')->controller(\App\Http\Controllers\TeamsController::class)->group(function () {
        Route::get('index', 'index')->name('index');

        Route::get('{team}/show', 'show')->name('show');
        Route::get('{team}/manage', 'edit')->name('manage');
        Route::post('{team}/manage', 'update');

        Route::get('{team}/members', 'members')->name('members');
        Route::post('{team}/members', 'updateMembers');
    });

    Route::prefix('gamemanage')->name('gamemanage.')->controller(\App\Http\Controllers\GameManageController::class)->group(function() {
        Route::get('index', 'index')->name('index');

        Route::get('create', 'create')->name('create');
        Route::post('create', 'store');

        Route::get('edit/{team}', 'edit')->name('edit');
        Route::post('edit/{team}', 'update');

        Route::get('delete/{team}', 'delete')->name('delete');
        Route::post('delete/{team}', 'destroy');
    })->middleware(['can:teams.management']);

    Route::prefix('user')->name('user.')->controller(\App\Http\Controllers\UserController::class)->group(function() {
        Route::get('edit', 'edit')->name('edit');
        Route::post('edit', 'update');
    });
});

Route::get('logout', [\Laravel\Fortify\Http\Controllers\AuthenticatedSessionController::class, 'destroy'])->middleware('auth');

Route::get('/', 'App\Http\Controllers\TeamsController@index')->middleware(['auth', 'verified'])->name('home');
